package com.mobi.demo;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebView;
import android.app.AlertDialog;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;

import com.mobi.sdk.MobiCopilot;
import com.google.android.material.bottomnavigation.BottomNavigationView;

import java.util.Map;

public class CopilotFragment extends Fragment {

    private final BottomNavigationView bottomNavigationView;

    public CopilotFragment(BottomNavigationView bottomNavigationView) {
        this.bottomNavigationView = bottomNavigationView;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_copilot, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        WebView webView = view.findViewById(R.id.webView);
        try {
            MobiCopilot mobiCopilot = new MobiCopilot.Builder()
                    .setUrl("")
                    .setAuthToken("")
                    .setWebView(webView)
                    .setCustomRouter(new MobiCopilot.MobiCopilotRouter() {
                        @Override
                        public void navigateTo(String routerKey, Map<String, Object> routerParams) {
                            MainActivity mainActivity = (MainActivity) getActivity();
                            if (bottomNavigationView != null && mainActivity != null) {
                                if (routerKey.equals("leave")) {
                                    mainActivity.setLeaveData(routerParams);
                                    bottomNavigationView.setSelectedItemId(R.id.nav_leave);
                                } else if (routerKey.equals("meeting")) {
                                    mainActivity.setMeetingData(routerParams);
                                    bottomNavigationView.setSelectedItemId(R.id.nav_meeting);
                                } else {
                                    showAlertDialog("未处理的功能路由", String.format("路由标识: %s", routerKey));
                                }
                            }
                        }

                        @Override
                        public void onNavigateError(String routerKey, MobiCopilot.MobiError error) {
                            showAlertDialog("功能路由错误", String.format("路由标识: %s\n错误码: %s\n错误信息: %s", routerKey, error.getCode(), error.getMessage()));
                        }
                    })
                    .build();
            mobiCopilot.loadCopilot(new MobiCopilot.MobiErrorListener() {
                @Override
                public void onError(MobiCopilot.MobiError error) {
                    showAlertDialog("运行时错误", String.format("错误码: %s\n错误信息: %s", error.getCode(), error.getMessage()));
                }
            });
        } catch (Exception e) {
            showAlertDialog("初始化错误", String.format("错误信息: %s", e.getMessage()));
        }
    }

    private void showAlertDialog(String title, String message) {
        new AlertDialog.Builder(getContext())
                .setTitle(title)
                .setMessage(message)
                .setPositiveButton("确定", null)
                .show();
    }
}