package com.mobi.demo;

import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;
import androidx.fragment.app.FragmentPagerAdapter;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.viewpager.widget.ViewPager;

import com.google.android.material.bottomnavigation.BottomNavigationView;

import java.util.Map;

public class MainActivity extends AppCompatActivity {

    private ViewPager viewPager;
    private BottomNavigationView bottomNavigationView;

    private final MutableLiveData<Map<String, Object>> leaveData = new MutableLiveData<>();
    private final MutableLiveData<Map<String, Object>> meetingData = new MutableLiveData<>();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        viewPager = findViewById(R.id.view_pager);
        viewPager.setOffscreenPageLimit(2);
        bottomNavigationView = findViewById(R.id.bottom_navigation);

        ViewPagerFragmentAdapter adapter = new ViewPagerFragmentAdapter(this, bottomNavigationView);
        viewPager.setAdapter(adapter);

        bottomNavigationView.setOnItemSelectedListener(item -> {
            int itemId = item.getItemId();
            if (itemId == R.id.nav_copilot) {
                viewPager.setCurrentItem(0, false);
                return true;
            } else if (itemId == R.id.nav_leave) {
                viewPager.setCurrentItem(1, false);
                return true;
            } else if (itemId == R.id.nav_meeting) {
                viewPager.setCurrentItem(2, false);
                return true;
            }
            return false;
        });

        viewPager.addOnPageChangeListener(new ViewPager.OnPageChangeListener() {
            @Override
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
                // No-op
            }

            @Override
            public void onPageSelected(int position) {
                switch (position) {
                    case 0:
                        bottomNavigationView.setSelectedItemId(R.id.nav_copilot);
                        break;
                    case 1:
                        bottomNavigationView.setSelectedItemId(R.id.nav_leave);
                        break;
                    case 2:
                        bottomNavigationView.setSelectedItemId(R.id.nav_meeting);
                        break;
                }
            }

            @Override
            public void onPageScrollStateChanged(int state) {
                // No-op
            }
        });
    }

    @SuppressWarnings("deprecation")
    private static class ViewPagerFragmentAdapter extends FragmentPagerAdapter {

        private final BottomNavigationView bottomNavigationView;

        public ViewPagerFragmentAdapter(@NonNull FragmentActivity fragmentActivity, BottomNavigationView bottomNavigationView) {
            super(fragmentActivity.getSupportFragmentManager(), BEHAVIOR_RESUME_ONLY_CURRENT_FRAGMENT);
            this.bottomNavigationView = bottomNavigationView;
        }

        @NonNull
        @Override
        public Fragment getItem(int position) {
            switch (position) {
                case 0:
                    return new CopilotFragment(bottomNavigationView);
                case 1:
                    return new LeaveFragment();
                default:
                    return new MeetingFragment();
            }
        }

        @Override
        public int getCount() {
            return 3;
        }
    }

    public LiveData<Map<String, Object>> getLeaveData() {
        return leaveData;
    }

    public void setLeaveData(Map<String, Object> newLeaveData) {
        leaveData.setValue(newLeaveData);
    }

    public LiveData<Map<String, Object>> getMeetingData() {
        return meetingData;
    }

    public void setMeetingData(Map<String, Object> newMeetingData) {
        meetingData.setValue(newMeetingData);
    }
}